@@ -8,5 +8,11 @@
 # John Machin (1705) computed 100 decimals of pi :
 pi - 4*(4*atan(1/5) - atan(1/239))
 
+## months in English
+month.name
+## months in your current locale
+format(ISOdate(2000, 1:12, 1), "%B")
+format(ISOdate(2000, 1:12, 1), "%b")
+
 
 
