@@ -18,7 +18,14 @@ sw[[1]]      # the same
 
 sw[1,]       # a one-row data frame
 sw[1,, drop=TRUE]  # a list
-
+## Don't show: 
+stopifnot(identical(sw[,1], sw[[1]]),
+          identical(sw[,1][1], 80.2),
+          identical(sw[,1, drop = FALSE], sw[1]),
+          is.data.frame(sw[1]), dim(sw[1] ) == c(5,1),
+          is.data.frame(sw[1,]),dim(sw[1,]) == c(1,4),
+          is.list(s1 <- sw[1,, drop=TRUE]), identical(s1$Fertility, 80.2))
+## End Don't show
 swiss[ c(1, 1:2), ]   # duplicate row, unique row names are created
 
 sw[sw <= 6] <- 6  # logical matrix indexing
