@@ -38,7 +38,7 @@ table(cut(y, breaks =  1*(-3:3), right = FALSE))
 ## sometimes the default dig.lab is not enough to be avoid confusion:
 aaa <- c(1,2,3,4,5,2,3,4,5,6,7)
 cut(aaa, 3)
-cut(aaa, 3, dig.lab=4)
+cut(aaa, 3, dig.lab=4, ordered = TRUE)
 
 
 
