@@ -1,7 +1,7 @@
 ### Name: list
 ### Title: Lists - Generic and Dotted Pairs
 ### Aliases: list pairlist alist as.list as.list.default as.list.data.frame
-###   as.list.environment as.pairlist is.list is.pairlist
+###   as.list.environment as.list.factor as.pairlist is.list is.pairlist
 ### Keywords: list manip
 
 ### ** Examples
@@ -10,14 +10,19 @@
 pts <- list(x=cars[,1], y=cars[,2])
 plot(pts)
 
+is.pairlist(.Options)  # a user-level pairlist
+
+## "pre-allocate" an empty list of length 5
+vector("list", 5)
+
 # Argument lists
-f <- function()x
+f <- function() x
 # Note the specification of a "..." argument:
-formals(f) <- al <- alist(x=, y=2, ...=)
+formals(f) <- al <- alist(x=, y=2+3, ...=)
 f
 al
 
-##environment->list coercion
+## environment->list coercion
 
 e1 <- new.env()
 e1$a <- 10
