@@ -5,13 +5,14 @@
 
 ### ** Examples
 
+## use character columns of names to get sensible sort order
 authors <- data.frame(
-    surname = c("Tukey", "Venables", "Tierney", "Ripley", "McNeil"),
+    surname = I(c("Tukey", "Venables", "Tierney", "Ripley", "McNeil")),
     nationality = c("US", "Australia", "US", "UK", "Australia"),
     deceased = c("yes", rep("no", 4)))
 books <- data.frame(
-    name = c("Tukey", "Venables", "Tierney",
-             "Ripley", "Ripley", "McNeil", "R Core"),
+    name = I(c("Tukey", "Venables", "Tierney",
+             "Ripley", "Ripley", "McNeil", "R Core")),
     title = c("Exploratory Data Analysis",
               "Modern Applied Statistics ...",
               "LISP-STAT",
