@@ -8,8 +8,8 @@
 options() # printing all current options
 op <- options(); str(op) # nicer printing
 
-options('width')[[1]] == options()$width # the latter needs more memory
-options(digits = 20)
+getOption("width") == options()$width # the latter needs more memory
+options(digits = 15)
 pi
 
 # set the editor, and save previous value
@@ -24,17 +24,19 @@ print(1e5)
 options(scipen=3); print(1e5)
 
 options(op)     # reset (all) initial options
-options('digits')
+options("digits")
 
 ## Not run: 
 ##D ## set contrast handling to be like S
 ##D options(contrasts = c("contr.helmert", "contr.poly"))
 ## End(Not run)
+
 ## Not run: 
 ##D ## on error, terminate the R session with error status 66
 ##D options(error = quote(q("no", status=66, runLast=FALSE)))
 ##D stop("test it")
 ## End(Not run)
+
 ## Not run: 
 ##D ## Set error actions for debugging:
 ##D ## enter browser on error, see ?recover:
