@@ -1,6 +1,6 @@
 ### Name: raw
 ### Title: Raw Vectors
-### Aliases: raw as.raw
+### Aliases: raw as.raw is.raw
 ### Keywords: classes
 
 ### ** Examples
@@ -14,6 +14,8 @@ x <- "A test string"
 (y <- charToRaw(x))
 is.vector(y) # TRUE
 rawToChar(y)
+is.raw(x)
+is.raw(y)
 
 isASCII <-  function(txt) all(charToRaw(txt) <= as.raw(127))
 isASCII(x)  # true
