@@ -37,7 +37,8 @@ plot(10^lx, y, log="xy", type="l", col="purple",
 plot(10^lx, y, log="xy", type="o", pch='.', col="forestgreen",
      main="Log-Log plot with custom axes", ylab=yl, xlab="x",
      axes = FALSE, frame.plot = TRUE)
-axis(1, at = my.at <- 10^(1:5), labels = formatC(my.at, format="fg"))
+my.at <- 10^(1:5)
+axis(1, at = my.at, labels = formatC(my.at, format="fg"))
 at.y <- 10^(-5:-1)
 axis(2, at = at.y, labels = formatC(at.y, format="fg"), col.axis="red")
 par(op)
