@@ -12,7 +12,7 @@ plot(cut(weight, 2) ~ group, data = PlantGrowth) # factor ~ factor
 plot(cut(weight, 3) ~ group, data = PlantGrowth,
      col = hcl(c(0, 120, 240), 50, 70))
 
-plot(PlantGrowth$group, axes=FALSE, main="no axes")# extremly silly
+plot(PlantGrowth$group, axes=FALSE, main="no axes")# extremely silly
 
 
 
