@@ -1,6 +1,7 @@
 ### Name: levelplot
 ### Title: Level Plots
-### Aliases: levelplot contourplot
+### Aliases: levelplot contourplot levelplot.formula contourplot.formula
+###   levelplot.matrix contourplot.matrix
 ### Keywords: hplot
 
 ### ** Examples
@@ -16,7 +17,6 @@ levelplot(z~x*y, grid, cuts = 50, scales=list(log="e"), xlab="",
 
 #S-PLUS example
 require(stats)
-data(environmental)
 attach(environmental)
 ozo.m <- loess((ozone^(1/3)) ~ wind * temperature * radiation,
        parametric = c("radiation", "wind"), span = 1, degree = 2)
@@ -28,11 +28,10 @@ wtr.marginal <- list(wind = w.marginal, temperature = t.marginal,
 grid <- expand.grid(wtr.marginal)
 grid[, "fit"] <- c(predict(ozo.m, grid))
 contourplot(fit ~ wind * temperature | radiation, data = grid,
-          cuts = 10, region = TRUE,
-          xlab = "Wind Speed (mph)",
-          ylab = "Temperature (F)",
-          main = "Cube Root Ozone (cube root ppb)",
-          col.regions = trellis.par.get("regions")$col)
+            cuts = 10, region = TRUE,
+            xlab = "Wind Speed (mph)",
+            ylab = "Temperature (F)",
+            main = "Cube Root Ozone (cube root ppb)")
 detach()
 
 
