@@ -29,5 +29,10 @@ showMethods("plot", classes = "track")
 ##D x = track, y = ANY
 ## End(Not run)
 
+not.there <- !any("package:stats4" == search())
+if(not.there) library(stats4)
+showMethods(class = "mle")
+if(not.there) detach("package:stats4")
+
 
 
