@@ -16,15 +16,15 @@ x3 <- runif(n, 0, 1)
 pi <- asin(1) * 2
 y <- 2 * sin(pi * x0)
 y <- y + exp(2 * x1) - 3.75887
-y <- y + 0.2 * x2^11 * (10 * (1 - x2))^6 + 10 * (10 * x2)^3 * (1 - x2)^10 - 1.396
+y <- y + 0.2 * x2^11 * (10 * (1 - x2))^6 + 10 * (10 * x2)^3 * (1 - x2)^10
 e <- rnorm(n, 0, sqrt(abs(sig2)))
 y <- y + e
 b<-gam(y~s(x0)+s(x1)+s(x2)+s(x3))
 plot(b,pages=1)
 summary(b)
 # now check the p-values by using a pure regression spline.....
-b.d<-round(b$edf)+1 
-b.d<-pmax(b.d,3) # can't have basis dimension less than this!
+b.d<-round(summary(b)$edf)+1 ## get edf per smooth
+b.d<-pmax(b.d,3) # can't have basis dimension less than 3!
 bc<-gam(y~s(x0,k=b.d[1],fx=TRUE)+s(x1,k=b.d[2],fx=TRUE)+
         s(x2,k=b.d[3],fx=TRUE)+s(x3,k=b.d[4],fx=TRUE))
 plot(bc,pages=1)
@@ -36,6 +36,7 @@ for (i in 1:k)
   p[i]<-summary(b)$s.p[1]
 }
 plot(((1:k)-0.5)/k,sort(p))
+abline(0,1,col=2)
 
 
 
