@@ -1,5 +1,5 @@
 ### Name: anova.mlm
-### Title: Comparisons between multivariate linear models
+### Title: Comparisons between Multivariate Linear Models
 ### Aliases: anova.mlm anova.mlmlist
 ### Keywords: regression models multivariate
 
@@ -7,7 +7,7 @@
 
 example(SSD) # Brings in the mlmfit and reacttime objects
 
-mlmfit0 <- update(mlmfit,~0)
+mlmfit0 <- update(mlmfit, ~0)
 
 ### Traditional tests of intrasubj. contrasts
 ## Using MANOVA techniques on contrasts:
@@ -26,6 +26,11 @@ anova(mlmfit, mlmfit0, M = ~ deg + noise, X = ~ noise, idata = idata,
 anova(mlmfit, mlmfit0, M = ~ deg + noise, X = ~ deg, idata = idata,
           test="Spherical" )
 
+f <- factor(rep(1:2,5)) # bogus, just for illustration
+mlmfit2 <- update(mlmfit, ~f)
+anova(mlmfit2, mlmfit, mlmfit0, X=~1, test="Spherical")
+anova(mlmfit2, X=~1, test="Spherical") # one-model form, eqiv. to previous 
+
 ### There seems to be a strong interaction in these data
 plot(colMeans(reacttime))
 
