@@ -1,6 +1,6 @@
 ### Name: contrast
 ### Title: Contrast Matrices
-### Aliases: contr.helmert contr.poly contr.sum contr.treatment
+### Aliases: contr.helmert contr.poly contr.sum contr.treatment contr.SAS
 ### Keywords: design regression array
 
 ### ** Examples
@@ -13,6 +13,9 @@ contr.helmert(4, contrasts = FALSE) # just the 4 x 4 identity matrix
 (cT <- contr.treatment(5))
 all(crossprod(cT) == diag(4)) # TRUE: even orthonormal
 
+(cP <- contr.SAS(5))
+all(crossprod(cP) == diag(4)) # TRUE: even orthonormal
+
 (cP <- contr.poly(3)) # Linear and Quadratic
 zapsmall(crossprod(cP), dig=15) # orthonormal up to fuzz
 
