@@ -1,6 +1,6 @@
 ### Name: dist
 ### Title: Distance Matrix Computation
-### Aliases: dist print.dist format.dist as.matrix.dist as.dist
+### Aliases: dist print.dist format.dist labels.dist as.matrix.dist as.dist
 ###   as.dist.default
 ### Keywords: multivariate cluster
 
@@ -14,14 +14,22 @@ m <- as.matrix(dist(x))
 d <- as.dist(m)
 stopifnot(d == dist(x))
 
+## Use correlations between variables ``as distance''
+dd <- as.dist((1 - cor(USJudgeRatings))/2)
+round(1000 * dd) # (prints more nicely)
+plot(hclust(dd)) # to see a dendrogram of clustered variables
+
 ## example of binary and canberra distances.
 x <- c(0, 0, 1, 1, 1, 1)
 y <- c(1, 0, 1, 1, 0, 1)
-dist(rbind(x,y), method="binary")
+dist(rbind(x,y), method= "binary")
 ## answer 0.4 = 2/5
-dist(rbind(x,y), method="canberra")
+dist(rbind(x,y), method= "canberra")
 ## answer 2 * (6/5)
 
+## To find the names
+labels(eurodist)
+
 ## Examples involving "Inf" :
 ## 1)
 x[6] <- Inf
